@@ -76,8 +76,11 @@ class AudioClip(Clip):
     @property
     def nchannels(self):
         return len(list(self.get_frame(0)))
-
-AudioClip.to_audiofile = ffmpeg_audiowrite
+    
+    def to_audiofile(self,filename, fps=44100, nbytes=2, buffersize=5000,
+                      codec='libvorbis', bitrate=None, verbose=True):
+        return ffmpeg_audiowrite(self,filename, fps, nbytes, buffersize,
+                      codec, bitrate, verbose)
 
 try:
     # Add methods preview (only if pygame installed)
